@@ -35,6 +35,7 @@ EV_Menu_Action::EV_Menu_Action(XAP_Menu_Id id,
 							   bool bHoldsSubMenu,
 							   bool bRaisesDialog,
 							   bool bCheckable,
+							   bool bRadio,
 							   const char * szMethodName,
 							   EV_GetMenuItemState_pFn pfnGetState,
 							   EV_GetMenuItemComputedLabel_pFn pfnGetLabel,
@@ -43,6 +44,7 @@ EV_Menu_Action::EV_Menu_Action(XAP_Menu_Id id,
 	  m_bHoldsSubMenu(bHoldsSubMenu),
 	  m_bRaisesDialog(bRaisesDialog),
 	  m_bCheckable(bCheckable),
+	  m_bRadio(bRadio),
 	  m_pfnGetState(pfnGetState),
 	  m_pfnGetLabel(pfnGetLabel),
 	  m_stScriptName(stScriptName)
@@ -67,10 +69,10 @@ bool EV_Menu_Action::hasDynamicLabel() const
 	return (m_pfnGetLabel != NULL);
 }
 
-const char * EV_Menu_Action::getDynamicLabel(XAP_Frame * pFrame, const EV_Menu_Label * pLabel) const
+const char * EV_Menu_Action::getDynamicLabel(const EV_Menu_Label * pLabel) const
 {
 	if (m_pfnGetLabel)
-		return m_pfnGetLabel(pFrame,pLabel,m_id);
+		return m_pfnGetLabel(pLabel,m_id);
 	else
 		return NULL;
 }
@@ -103,6 +105,11 @@ bool EV_Menu_Action::isCheckable() const
 	return m_bCheckable;
 }
 
+bool EV_Menu_Action::isRadio() const
+{
+	return m_bRadio;
+}
+
 /*****************************************************************/
 /*****************************************************************/
 
@@ -123,7 +130,7 @@ EV_Menu_ActionSet::EV_Menu_ActionSet(XAP_Menu_Id first, XAP_Menu_Id last)
 	size_t i;
 	
 	for (i = 0; i < nb_items; ++i)
-		m_actionTable.addItem(0);
+		m_actionTable.addItem(NULL);
 }
 
 EV_Menu_ActionSet::~EV_Menu_ActionSet()
@@ -135,22 +142,22 @@ bool EV_Menu_ActionSet::setAction(XAP_Menu_Id id,
 								  bool bHoldsSubMenu,
 								  bool bRaisesDialog,
 								  bool bCheckable,
+								  bool bRadio,
 								  const char * szMethodName,
 								  EV_GetMenuItemState_pFn pfnGetState,
 								  EV_GetMenuItemComputedLabel_pFn pfnGetLabel,
 								  const UT_String& stScriptName)
 {
-	void *tmp;
+	EV_Menu_Action * pTmpAction;
 
-	if ((id < m_first) || (id >= m_first + (UT_sint32)m_actionTable.size()))
+	if ((id < m_first) || (id >= m_first + static_cast<UT_sint32>(m_actionTable.size())))
 		return false;
 
 	UT_uint32 index = (id - m_first);
-	EV_Menu_Action *pAction = new EV_Menu_Action(id, bHoldsSubMenu, bRaisesDialog, bCheckable,
+	EV_Menu_Action *pAction = new EV_Menu_Action(id, bHoldsSubMenu, bRaisesDialog, bCheckable, bRadio,
 												 szMethodName, pfnGetState, pfnGetLabel, stScriptName);
-	UT_uint32 error = m_actionTable.setNthItem(index, pAction, &tmp);
+	UT_uint32 error = m_actionTable.setNthItem(index, pAction, &pTmpAction);
 
-	EV_Menu_Action * pTmpAction = static_cast<EV_Menu_Action *> (tmp);
 	DELETEP(pTmpAction);
 	return (error == 0);
 }
@@ -158,7 +165,7 @@ bool EV_Menu_ActionSet::setAction(XAP_Menu_Id id,
 const EV_Menu_Action * EV_Menu_ActionSet::getAction(XAP_Menu_Id id) const
 {
 	xxx_UT_DEBUGMSG(("JCA: EV_Menu_ActionSet::getAction(%d) m_first = [%d], size_table = [%d]\n", id, m_first, m_actionTable.size()));
-	if ((id < m_first) || (id > m_first + (UT_sint32)m_actionTable.size()))
+	if ((id < m_first) || (id > m_first + static_cast<UT_sint32>(m_actionTable.size())))
 		return NULL;
 
 	UT_uint32 index = (id - m_first);
@@ -176,7 +183,8 @@ bool EV_Menu_ActionSet::addAction(EV_Menu_Action *pAction)
 				 pAction->getMenuId(), size_table, m_first));
 
 #ifdef DEBUG
-	if (pAction->getMenuId() < (UT_sint32)size_table + m_first - 1 || pAction->getMenuId() > (UT_sint32)size_table + m_first)
+	if (pAction->getMenuId() < static_cast<UT_sint32>(size_table) + m_first - 1
+			|| pAction->getMenuId() > static_cast<UT_sint32>(size_table) + m_first)
 		UT_DEBUGMSG(("WARNING: Weird menu id.\n"));
 #endif
 	m_actionTable.insertItemAt(pAction, pAction->getMenuId() - m_first);
