@@ -749,6 +749,9 @@ void GR_UnixGraphics::setZoomPercentage(UT_uint32 iZoom)
 	// zoom level.
 	if (m_pFont)
 		m_pXftFontD = m_pFont->getDeviceXftFont(iZoom);
+	DELETEP(m_pFontGUI);
+	m_pFontGUI = NULL;
+	m_pFontGUI = static_cast<XAP_UnixFontHandle*>(getGUIFont());
 }
 
 static GdkCapStyle mapCapStyle ( GR_Graphics::CapStyle in )
@@ -844,7 +847,8 @@ void GR_UnixGraphics::drawGlyph(UT_uint32 Char, UT_sint32 xoff, UT_sint32 yoff)
 		iChar =  FT_Get_Char_Index(face,Char);
 		XftUnlockFace (m_pXftFontD);
 	}
-	
+	if(m_pXftFontD == NULL)
+		return;
 	// FIXME ascent in wrong unit
 
 	UT_sint32 idy = _tduY(yoff);
@@ -860,13 +864,14 @@ void GR_UnixGraphics::drawChars(const UT_UCSChar* pChars, int iCharOffset,
 	xxx_UT_DEBUGMSG(("UnixGraphics:drawChars: m_bIsSymbol %d iLength %d \n",m_bIsSymbol,iLength));
 	if (iLength == 0)
 		return;
+	if(m_pXftFontD == NULL)
+		return;
 	// FIXME shouldn't need to do this - plam
 	UT_sint32 idy = _tduY(yoff);
 	UT_sint32 idx = _tduX(xoff);
 
 	//	UT_sint32 iAscent = m_pXftFontL->ascent * getResolution() / s_getDeviceResolution();
 	UT_sint32 iAscent = getFontAscent();
-
 	if (!pCharWidths)
 	{
 		if(!isSymbol() && !isDingbat())
@@ -1218,7 +1223,8 @@ GR_Font * GR_UnixGraphics::_findFont(const char* pszFontFamily,
 															  pszFontStretch, pszFontSize,this);
 
 	// bury the pointer to our Unix font in a XAP_UnixFontHandle with the correct size.
-	UT_uint32 iSize = static_cast<UT_uint32>(UT_convertToPoints(pszFontSize));
+	UT_uint32 iSize = static_cast<UT_uint32>(UT_convertToPoints(pszFontSize)*s_getDeviceResolution()/72.);
+
 	XAP_UnixFontHandle* pFont = new XAP_UnixFontHandle(pUnixFont, iSize);
 	UT_ASSERT(pFont);
 	xxx_UT_DEBUGMSG(("Return Font name %s \n",pUnixFont->getName())); 
@@ -1855,6 +1861,7 @@ GR_Image * GR_UnixGraphics::genImageFromRectangle(const UT_Rect &rec)
 
 	GR_UnixImage * pImg = new GR_UnixImage("ScreenShot");
 	pImg->m_image = pix;
+	pImg->setDisplaySize(idw,idh);
 	return static_cast<GR_Image *>(pImg);
 }
 
