@@ -125,6 +125,7 @@ GR_Graphics::GR_Graphics()
 	  m_iZoomPercentage(100),
 	  m_iFontAllocNo(0),
 	  m_pRect(NULL),
+	  m_bHave3DColors(false),
 	  m_pCaret(NULL),
 	  m_bIsPortrait(true),
 	  m_bSpawnedRedraw(false),
@@ -358,10 +359,6 @@ void GR_Graphics::setZoomPercentage(UT_uint32 iZoom)
 	m_iFontAllocNo = 0xffffffff;
 }
 
-UT_uint32 GR_Graphics::getZoomPercentage(void) const
-{
-	return m_iZoomPercentage;
-}
 
 const char * GR_Graphics::invertDimension(UT_Dimension dim, double dValue) const
 {
@@ -418,6 +415,27 @@ void GR_Graphics::drawImage(GR_Image* pImg, UT_sint32 xDest, UT_sint32 yDest)
      pImg->render(this, xDest, yDest);
 }
 
+/*!
+    This method is just like drawChars() except it treats yoff as position of the font
+    baseline. The default implementation simply subtracts the ascent of the current font
+    from yoff and calls drawChars(), which should work on all platforms except for win32.
+
+    On win32 because of the trickery we use to achieve wysiwyg layout the acent of the
+    font we work with is slightly smaller than that of the actual font the system uses to
+    draw on the screen. As a result, the characters end up positioned slightly higher than
+    they should and this has proved a problem in the math plugin (see screen shots in #9500)
+*/
+void GR_Graphics::drawCharsRelativeToBaseline(const UT_UCSChar* pChars,
+								 int iCharOffset,
+								 int iLength,
+								 UT_sint32 xoff,
+								 UT_sint32 yoff,
+								 int* pCharWidths)
+{
+	drawChars(pChars, iCharOffset, iLength, xoff, yoff - getFontAscent(), pCharWidths);
+}
+
+
 /*!
  * Create a new image from the Raster rgba byte buffer defined by pBB.
  * The dimensions of iWidth and iHeight are in logical units but the image
@@ -622,7 +640,7 @@ void GR_Graphics::setDoMerge( bool bMergeState)
  * already existing expose rectangle to cover the expose rectangle of
  *  the current event or if there is no pending expose rectangle, because
  *  the background repainter has cleared it, set a new expose rectangle.
-\params UT_Rect *rClip the rectangle of the expose event.
+\param UT_Rect *rClip the rectangle of the expose event.
 */
 void GR_Graphics::doRepaint( UT_Rect * rClip)
 {
@@ -756,8 +774,9 @@ bool GR_Graphics::itemize(UT_TextIterator & text, GR_Itemization & I)
 		UT_return_val_if_fail(text.getStatus() == UTIter_OK, false);
 
 		iType = UT_bidiGetCharType(c);
-#if 1
-		// this brach of code breaks at all direction bounaries
+#if 0
+		// this branch of code breaks at all direction bounaries
+		// it is disabled because doing that causes bug 8099
 		iCurOffset = iLastOffset = text.getPosition();
 		++text;
 		
@@ -1099,20 +1118,67 @@ void GR_Graphics::renderChars(GR_RenderInfo & ri)
 
 /*!
     return true if linebreak at character c is permissible
-    the built-in class is too simple to differentiate between breaks before and after character
 */
-bool GR_Graphics::canBreak(GR_RenderInfo & ri, UT_sint32 &iNext, bool /* bAfter */)
+bool GR_Graphics::canBreak(GR_RenderInfo & ri, UT_sint32 &iNext, bool bAfter)
 {
-	iNext = -1; // we do not bother with this
-	UT_return_val_if_fail(ri.m_pText && ri.m_pText->getStatus() == UTIter_OK, false);
-	
-	*(ri.m_pText) += ri.m_iOffset;
-	UT_return_val_if_fail(ri.m_pText->getStatus() == UTIter_OK, false);
-	
-	UT_UCS4Char c = ri.m_pText->getChar();
+	UT_UCS4Char c[2];
 
+	// Default to -1.
+	iNext = -1; 
+
+	// Check the iterator is OK.
+	UT_return_val_if_fail(ri.m_pText && ri.m_pText->getStatus() == UTIter_OK, false);
+
+	// Advance the iterator by the given offset.
+	*(ri.m_pText) += ri.m_iOffset;
+	// Check that we haven't run off the end of the iterator.
+	UT_return_val_if_fail(ri.m_pText->getStatus() == UTIter_OK, false);
+
+	// Fetch a pointer to the Encoding manager.
 	UT_return_val_if_fail(getApp(), false);
-	return getApp()->getEncodingManager()->can_break_at(c);
+	const XAP_EncodingManager *encMan = getApp()->getEncodingManager();
+	UT_return_val_if_fail(encMan, false);
+
+	// Set up c[] appropriately depending on whether we're looking
+	// for break before or after.
+	if (bAfter)
+	{
+		c[1] = ri.m_pText->getChar();
+	}
+	else
+	{
+		--(*ri.m_pText);  
+		c[1] = ri.m_pText->getChar();
+	}
+
+	// Make sure we managed to get the character we wanted.
+	if (c[1] == UT_IT_ERROR)
+		return false;
+
+	UT_uint32 iCount = ri.m_iOffset;
+	do
+	{
+		++(*ri.m_pText);
+		c[0] = c[1];
+		c[1] = ri.m_pText->getChar();
+
+		// If we reach the end of the document then return false
+		// (and leave iNext set to -1).
+		if (c[1] == UT_IT_ERROR)
+			return false;
+		iCount++;
+	}
+	while (!encMan->canBreakBetween(c));
+
+	// Set iNext.
+	iNext = iCount - 1;
+
+	// If a break was possible between the first character pair
+	// then return true. 
+	if (iNext == ri.m_iOffset)
+		return true;
+	// ...otherwise, return false.
+	return false;
 }
 
 /*!
