@@ -21,6 +21,9 @@
 #include "ut_timer.h"
 #include "ut_assert.h"
 
+// declare static member
+static UT_GenericVector<UT_Timer*> static_vecTimers;
+
 UT_Timer::UT_Timer()
 	: m_iIdentifier(0)
 {
@@ -38,8 +41,10 @@ UT_Timer::~UT_Timer()
 	}
 }
 
-// declare static member
-UT_Vector UT_Timer::static_vecTimers;
+UT_GenericVector<UT_Timer*> & UT_Timer::_getVecTimers ()
+{ 
+	return static_vecTimers;
+}
 
 void UT_Timer::setIdentifier(UT_uint32 iIdentifier)
 {
@@ -66,7 +71,7 @@ UT_Timer* UT_Timer::findTimer(UT_uint32 iIdentifier)
 	int count = static_vecTimers.getItemCount();
 	for (int i=0; i<count; i++)
 	{
-		UT_Timer* pTimer = (UT_Timer*) static_vecTimers.getNthItem(i);
+		UT_Timer* pTimer = static_vecTimers.getNthItem(i);
 		UT_ASSERT(pTimer);
 		
 		if (pTimer->getIdentifier() == iIdentifier)
