@@ -17,6 +17,12 @@
  * 02111-1307, USA.
  */
 
+/*
+ * Port to Maemo Development Platform 
+ * Author: INdT - Renato Araujo <renato.filho@indt.org.br>
+ */
+
+#include <glib.h>
 #include <gtk/gtkwidget.h>
 #include <gtk/gtkmain.h>
 #include <gdk/gdkrgb.h>
@@ -32,87 +38,126 @@
 #include "ut_debugmsg.h"
 #include "xap_UnixDialogHelper.h"
 #include "ut_string.h"
+#include "ut_uuid.h"
 
 #include "xap_Strings.h"
 #include "xap_Args.h"
 #include "xap_UnixApp.h"
 #include "xap_FakeClipboard.h"
 #include "gr_UnixImage.h"
-#include "xap_UnixFrame.h"
 #include "xap_UnixToolbar_Icons.h"
 #include "xap_Unix_TB_CFactory.h"
 #include "xap_Prefs.h"
 #include "xap_UnixEncodingManager.h"
 #include "xap_UnixFontManager.h"
+
 #include "xap_UnixNullGraphics.h"
+#include "xap_UnixPSGraphics.h"
+#include "gr_UnixGraphics.h"
+#include "gr_UnixPangoGraphics.h"
+
+UnixNull_Graphics * abi_unixnullgraphics_instance = 0;
 
 /*****************************************************************/
+// #include <sys/time.h> // tmp just to measure the time that XftInit takes
 
 XAP_UnixApp::XAP_UnixApp(XAP_Args * pArgs, const char * szAppName)
 	: XAP_App(pArgs, szAppName), m_dialogFactory(this), m_controlFactory()
 {
+#if FC_MINOR > 2
+	FcInit();
+#else
+	XftInit(NULL);
+#endif
+
 	m_pUnixToolbarIcons = 0;
 
 	_setAbiSuiteLibDir();
 
-	// set some generic window sizes and positions
-	m_geometry.x = 1;
-	m_geometry.y = 1;
-	m_geometry.width = 600;
-	m_geometry.height = 600;
+	memset(&m_geometry, 0, sizeof(m_geometry));
 
-	// by default, which will be applied if the user does NOT
-	// specify a --geometry argument, we only want to obey the
-	// size (which is set above), not a position.
-	m_geometry.flags = GEOMETRY_FLAG_SIZE;
-	m_bBonoboRunning = false;
-	// hack to ensure UnixNull_Graphics is linked properly
-	// this condition should be false always
-	if (this == 0)
+	// create an instance of UT_UUIDGenerator or appropriate derrived class
+	_setUUIDGenerator(new UT_UUIDGenerator());
+
+	// register graphics allocator
+	GR_GraphicsFactory * pGF = getGraphicsFactory();
+	UT_ASSERT( pGF );
+
+	if(pGF)
 	{
-		UnixNull_Graphics * pUN_G = new UnixNull_Graphics(0,0);
+		bool bSuccess = pGF->registerClass(GR_UnixGraphics::graphicsAllocator,
+										   GR_UnixGraphics::graphicsDescriptor,
+										   GR_UnixGraphics::s_getClassId());
+
+		// we are in deep trouble if this did not succeed
+		UT_ASSERT( bSuccess );
+		pGF->registerAsDefault(GR_UnixGraphics::s_getClassId(), true);
+
+		bSuccess = pGF->registerClass(PS_Graphics::graphicsAllocator,
+									  PS_Graphics::graphicsDescriptor,
+									  PS_Graphics::s_getClassId());
+
+		UT_ASSERT( bSuccess );
+		pGF->registerAsDefault(PS_Graphics::s_getClassId(), false);
+		
+
+		bSuccess = pGF->registerClass(UnixNull_Graphics::graphicsAllocator,
+									  UnixNull_Graphics::graphicsDescriptor,
+									  UnixNull_Graphics::s_getClassId());
+
+		
+		UT_ASSERT( bSuccess );
+#if 1
+		bSuccess = pGF->registerClass(GR_UnixPangoGraphics::graphicsAllocator,
+									  GR_UnixPangoGraphics::graphicsDescriptor,
+									  GR_UnixPangoGraphics::s_getClassId());
+
+		UT_ASSERT( bSuccess );
+#endif
 	}
+
+	/* We need to link UnixNull_Graphics because the AbiCommand
+	 * plugin uses it.
+	 */
+	if (abi_unixnullgraphics_instance)
+	  {
+	    delete abi_unixnullgraphics_instance;
+	    //abi_unixnullgraphics_instance = new UnixNull_Graphics(0,0);
+		XAP_UnixNullGraphicsAllocInfo ai(NULL, NULL);
+		abi_unixnullgraphics_instance = (UnixNull_Graphics*) XAP_App::getApp()->newGraphics(GRID_UNIX_NULL, ai);
+	  }
+	  
 }
 
 XAP_UnixApp::~XAP_UnixApp()
 {
 	DELETEP(m_pUnixToolbarIcons);
-	DELETEP(m_fontManager);
+	
+	delete m_fontManager;
+
+#if FC_MINOR > 2
+	FcFini();
+#endif
 }
 
-bool XAP_UnixApp::initialize()
+bool XAP_UnixApp::initialize(const char * szKeyBindingsKey, const char * szKeyBindingsDefaultValue)
 {
-	// initialize GTK first.
-	
-	gtk_set_locale();
-
-#ifndef ABI_OPT_WIDGET
-	gtk_init(&m_pArgs->m_argc,&m_pArgs->m_argv);
-#endif
+	if (!g_thread_supported ()) g_thread_init (NULL);
 
 	// let our base class do it's thing.
 	
-	XAP_App::initialize();
+	XAP_App::initialize(szKeyBindingsKey, szKeyBindingsDefaultValue);
 
 	/*******************************/
 
 	// load the font stuff from the font directory
-
+	UT_DEBUGMSG(("Loading Fonts\n"));
 	if (!_loadFonts())
 		return false;
+	UT_DEBUGMSG(("Fonts Loaded \n"));
 	
 	/*******************************/
-
-	// set up new widgets so that they work well with gdkrgb functions
-	//gtk_widget_push_visual(gtk_preview_get_visual());
-	//gtk_widget_push_colormap(gtk_preview_get_cmap());
-
-	gdk_rgb_init();
-	gtk_widget_set_default_colormap(gdk_rgb_get_cmap());
-	gtk_widget_set_default_visual(gdk_rgb_get_visual());
-
-	/*******************************/
-  
+	
 	// load only one copy of the platform-specific icons.
 	
 	m_pUnixToolbarIcons = new AP_UnixToolbar_Icons();
@@ -124,6 +169,7 @@ bool XAP_UnixApp::initialize()
 
 void XAP_UnixApp::reallyExit()
 {
+	
 	gtk_main_quit();
 }
 
@@ -142,13 +188,13 @@ XAP_Toolbar_ControlFactory * XAP_UnixApp::getControlFactory()
 	return &m_controlFactory;
 }
 
-XAP_UnixFontManager * XAP_UnixApp::getFontManager()
+XAP_UnixFontManager * XAP_UnixApp::getFontManager() const
 {
 	return m_fontManager;
 }
 
-void XAP_UnixApp::setGeometry(int x, int y, UT_uint32 width, UT_uint32 height,
-							  windowGeometryFlags flags)
+void XAP_UnixApp::setWinGeometry(int x, int y, UT_uint32 width, UT_uint32 height,
+								 UT_uint32 flags)
 {
 	// TODO : do some range checking?
 	m_geometry.x = x;
@@ -158,8 +204,8 @@ void XAP_UnixApp::setGeometry(int x, int y, UT_uint32 width, UT_uint32 height,
 	m_geometry.flags = flags;
 }
 
-void XAP_UnixApp::getGeometry(int * x, int * y, UT_uint32 * width,
-							  UT_uint32 * height, windowGeometryFlags * flags)
+void XAP_UnixApp::getWinGeometry(int * x, int * y, UT_uint32 * width,
+								 UT_uint32 * height, UT_uint32 * flags)
 {
 	UT_ASSERT(x && y && width && height);
 	*x = m_geometry.x;
@@ -199,89 +245,24 @@ const char * XAP_UnixApp::getUserPrivateDirectory()
 bool XAP_UnixApp::_loadFonts()
 {
 	// create a font manager for our app to use
-	UT_uint32 relativePathsSoFar = 0, relativePathCount = 0;
-	UT_uint32 i = 0;
-	
 	m_fontManager = new XAP_UnixFontManager();
+	XAP_UnixFontManager::pFontManager = m_fontManager; // set the static variable pFontManager, so we can access our fontmanager from a static context
 	UT_ASSERT(m_fontManager);
 
-	// find all the fonts in the appropriate places.  the list of directories
-	// is given in a preferences variable.
-
-	char * szTemp = NULL;
-	const char * szPrefFontPath = NULL;
-	getPrefsValue(XAP_PREF_KEY_UnixFontPath,
-		      (const XML_Char**)&szPrefFontPath);
-	UT_ASSERT((szPrefFontPath) && (*szPrefFontPath));
-
- 	for (i = 0; szPrefFontPath[i]; i++)
-  	{
-  		// count the number of segments in the path
-  		// path looks like: "/font/dir;dir/anotherdir;/more/fonts"
-  		if( ((i == 0) || (szPrefFontPath[i-1] == ';')) && (szPrefFontPath[i] != '/'))
-  			relativePathCount++;
-  	}
-  	
-  	// cache the suiteDir's name and length instead of calculating
-  	// them on every loop
-	char * suiteDirCache = (char *)getAbiSuiteLibDir();
-  	UT_uint32 suiteLenCache = strlen(suiteDirCache);
-
- 	// make pointer to the font path. ignore the cast to make gcc shut up
-	char *szPrefFontPathPtr = (char *)szPrefFontPath;
-
-	for (i = 0; szPrefFontPathPtr[i]; i++)
- 		if ( ((i == 0) || (szPrefFontPathPtr[i-1] == ';')) && (szPrefFontPathPtr[i] != '/'))
- 		{
-		        // if relative path in prefs, prepend library directory.
- 			szTemp = (char *)UT_calloc(suiteLenCache + strlen(szPrefFontPathPtr) + 10, sizeof(char));
- 			strcpy(szTemp, szPrefFontPathPtr);
- 			sprintf(szTemp + i, "%s/%s", suiteDirCache, szPrefFontPathPtr + i);
- 			
- 			// if relativePathsSoFar > 1 then szPrefFontPathPtr
- 			// was really szTemp and was allocated by our call to
- 			// UT_calloc so we must free it. also, we are sure not to
-			// free the memory pointed to by getPrefsValue()
- 			if (relativePathsSoFar && szPrefFontPathPtr)
- 				free(szPrefFontPathPtr);
- 			
- 			szPrefFontPathPtr = szTemp;
- 			relativePathsSoFar++;
- 		}
- 
- 	// HUH? These don't match somehow. Abort!!
- 	UT_ASSERT(relativePathsSoFar == relativePathCount);
-	//UT_DEBUGMSG(("Using FontPath from preferences [%s].\n",szPrefFontPathPtr));
-	m_fontManager->setFontPath(szPrefFontPathPtr);
-	FREEP(szTemp);
-	
 	// let it loose
-
+	UT_DEBUGMSG(("Scavange Fonts started \n"));
 	if (!m_fontManager->scavengeFonts())
 		return false;
 	
-#if 0
-#ifdef DEBUG
-	XAP_UnixFont ** fonts = m_fontManager->getAllFonts();
-	UT_DEBUGMSG(("Found Fonts:\n"));
-	for (i = 0; i < m_fontManager->getCount(); i++)
-	{
-		UT_DEBUGMSG(("\tName [%s] at [%s], metrics [%s]\n",
-					 fonts[i]->getName(), fonts[i]->getFontfile(),
-					 fonts[i]->getMetricfile()));
-	}
-
-	DELETEP(fonts);
-#endif
-#endif
-
+	UT_DEBUGMSG(("Scavange Fonts finished \n"));
 	return true;
 }
 
 void XAP_UnixApp::_setAbiSuiteLibDir()
 {
+	// FIXME: this code sucks hard
+
 	char buf[PATH_MAX];
-//	char buf2[PATH_MAX]; // not used?
 
 	// see if a command line option [-lib <AbiSuiteLibraryDirectory>] was given
 
@@ -321,15 +302,9 @@ void XAP_UnixApp::_setAbiSuiteLibDir()
 		return;
 	}
 
-	// TODO what to do ??  try the current directory...
-	
-	UT_DEBUGMSG(("ABISUITE_HOME not set and -lib not given.  Assuming current directory....\n"));
+	// otherwise, use the hard-coded value
+	XAP_App::_setAbiSuiteLibDir(getAbiSuiteHome());
 
-	getcwd(buf,sizeof(buf));
-	int len = strlen(buf);
-	if (buf[len-1]=='/')				// trim trailing slash
-		buf[len-1] = 0;
-	XAP_App::_setAbiSuiteLibDir(buf);
 	return;
 }
 
