@@ -133,8 +133,18 @@ XAP_App::~XAP_App()
 
 	// run thru and destroy all frames on our window list.
 	UT_VECTOR_PURGEALL(XAP_Frame *, m_vecFrames);
+	//
+	// If the Embed plugins exist but aren't used the pointers
+	// are NULL. We used code instead of getting asserts
+	// for UT_VECTOR_PURGEALL
+	//
+	UT_sint32 i = 0;
+	for(i= 0; i<  m_vecEmbedManagers.getItemCount(); i++)
+	{
+	    GR_EmbedManager  * p = m_vecEmbedManagers.getNthItem(i);
+	    DELETEP(p);
+	}
 
-	UT_VECTOR_PURGEALL(GR_EmbedManager  *, m_vecEmbedManagers);
 
 	FREEP(m_szAbiSuiteLibDir);
 	DELETEP(m_pEMC);
@@ -242,21 +252,23 @@ XAP_Module * XAP_App::getPlugin(const char * szPluginName)
  */
 UT_uint32 XAP_App::registerEmbeddable(GR_EmbedManager * pEmbed)
 {
+	 UT_return_val_if_fail( pEmbed, 0xFFFFFFF );
+	 
      UT_sint32 i=0;
      bool bFound = false;
      GR_EmbedManager * pCur = NULL;
      for(i=0; !bFound && (i< static_cast<UT_sint32>(m_vecEmbedManagers.getItemCount())); i++)
      {
-       pCur =  m_vecEmbedManagers.getNthItem(i);
-       if(UT_strcmp(pCur->getObjectType(),pEmbed->getObjectType()) == 0)
-       {
-	 bFound = true;
-       }
+		 pCur =  m_vecEmbedManagers.getNthItem(i);
+		 if(UT_strcmp(pCur->getObjectType(),pEmbed->getObjectType()) == 0)
+		 {
+			 bFound = true;
+		 }
      }
      if(!bFound)
      {
-       m_vecEmbedManagers.addItem(pEmbed);
-       return  m_vecEmbedManagers.getItemCount() - 1;
+		 m_vecEmbedManagers.addItem(pEmbed);
+		 return  m_vecEmbedManagers.getItemCount() - 1;
      }
      return 0xFFFFFFF;
 }
@@ -604,6 +616,17 @@ const char * XAP_App::getApplicationName() const
 	return m_szAppName;
 }
 
+void XAP_App::rebuildMenus(void)
+{
+	UT_uint32 frameCount = getFrameCount();
+
+	for (UT_uint32 i = 0; i < frameCount; i++)
+		if (XAP_Frame * pFrame = getFrame(i))
+		{
+			pFrame->rebuildMenus();
+		}
+}
+
 EV_EditMethodContainer * XAP_App::getEditMethodContainer() const
 {
 	return m_pEMC;
