@@ -22,7 +22,15 @@
 #ifndef XAP_EDITMETHOD_H
 #define XAP_EDITMETHOD_H
 
-EV_EditMethodContainer * AP_GetEditMethods(void);
+/* pre-emptive dismissal; ut_types.h is needed by just about everything,
+ * so even if it's commented out in-file that's still a lot of work for
+ * the preprocessor to do...
+ */
+#ifndef UT_TYPES_H
+#include "ut_types.h"
+#endif
+
+ABI_EXPORT EV_EditMethodContainer * AP_GetEditMethods(void);
 
 #endif /* XAP_EDITMETHOD_H */
 
