@@ -199,8 +199,10 @@ public:
 	UT_Error		cmdDeleteHyperlink();
 	bool                    cmdInsertMathML(const char * szFileName,
 						PT_DocPosition pos);
-	bool                    cmdInsertEmbed(UT_ByteBuf * pBuf,PT_DocPosition pos,const char * szMime,const char * szProps);
-	bool                    cmdUpdateEmbed(UT_ByteBuf * pBuf, const char * szMime, const char * szProps);
+	bool	        cmdInsertEmbed(UT_ByteBuf * pBuf,PT_DocPosition pos,const char * szMime,const char * szProps);
+	bool            cmdUpdateEmbed(UT_ByteBuf * pBuf, const char * szMime, const char * szProps);
+	bool	        cmdUpdateEmbed(fp_Run * pRun, UT_ByteBuf * pBuf, const char * szMime, const char * szProps);
+	bool	        cmdDeleteEmbed(fp_Run * pRun);
 
 	bool                    cmdInsertLatexMath(UT_UTF8String & sLatex,
 						   UT_UTF8String & sMath);
