@@ -1,6 +1,8 @@
+/* -*- mode: C++; tab-width: 4; c-basic-offset: 4; -*- */
+
 /* AbiWord
  * Copyright (C) 1998 AbiSource, Inc.
- * Copyright (C) 2003 Hubert Figuiere
+ * Copyright (C) 2003, 2005 Hubert Figuiere
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -122,7 +124,6 @@ void AP_CocoaDialog_Lists::runModal( XAP_Frame * pFrame)
 
 void AP_CocoaDialog_Lists::runModeless (XAP_Frame * pFrame)
 {
-	NSWindow* window;
 	m_dlg = [[AP_CocoaDialog_ListsController alloc] initFromNib];
 	[m_dlg setXAPOwner:this];
 	
@@ -130,13 +131,15 @@ void AP_CocoaDialog_Lists::runModeless (XAP_Frame * pFrame)
 	// Save dialog the ID number and pointer to the widget
 	UT_sint32 sid = (UT_sint32) getDialogId ();
 	m_pApp->rememberModelessId(sid, (XAP_Dialog_Modeless *) m_pDialog);
-	window = [m_dlg window];
+
+	NSPanel * window = (NSPanel *) [m_dlg window];
 
 	// Populate the dialog
 	updateDialog();
 	m_bDontUpdate = false;
 
 	// Now Display the dialog
+	[window setBecomesKeyOnlyIfNeeded:YES];
 	[window orderFront:m_dlg];
 
 	// make a new Cocoa GC
@@ -189,13 +192,17 @@ void AP_CocoaDialog_Lists::autoupdateLists(UT_Worker * pWorker)
 
 void AP_CocoaDialog_Lists::setFoldLevelInGUI(void)
 {
-	UT_ASSERT(0);
+	[m_dlg selectFolding:getCurrentFold()];
 }
 
 bool AP_CocoaDialog_Lists::isPageLists(void)
 {
-	UT_ASSERT(0);
-	return true;
+	if(isModal())
+	{
+		return true;
+	}
+
+	return [m_dlg selectedTab] == 0;
 }
 
 void AP_CocoaDialog_Lists::previewExposed(void)
@@ -223,9 +230,13 @@ void AP_CocoaDialog_Lists::destroy(void)
 		setAnswer(AP_Dialog_Lists::a_CLOSE);
 
 		modeless_cleanup();
-		[[m_dlg window] performClose:m_dlg];
+
+		[m_dlg close];
+		[m_dlg release];
+		m_dlg = 0;
+
 		DELETEP(m_pAutoUpdateLists);
-		DELETEP (m_pPreviewWidget);
+		DELETEP(m_pPreviewWidget);
 	}
 }
 
@@ -395,13 +406,21 @@ void AP_CocoaDialog_Lists::_fillFontMenu(NSPopUpButton* menu)
 
 	for(i = 0; i < nfonts; i++)
 	{
+		[menu addItemWithTitle:[list objectAtIndex:i]];
+		[[menu lastItem] setTag:(i + 1)];
+#if 0
 		NSMenuItem* item = [[NSMenuItem alloc] initWithTitle:[list objectAtIndex:i]
 				action:nil keyEquivalent:@""];
 		[item setTag:i+1];
 		[[menu menu] addItem:item];
+#endif
 	}
 }
 
+const XML_Char* AP_CocoaDialog_Lists::_getDingbatsFontName() const
+{
+	return "Zapf Dingbats";
+}
 
 void AP_CocoaDialog_Lists::_fillNoneStyleMenu(NSMenu *listmenu)
 {
@@ -712,6 +731,15 @@ void AP_CocoaDialog_Lists::_gatherData(void)
 	LocalizeControl(_applyToCurrentBtn, pSS, AP_STRING_ID_DLG_Lists_Apply_Current);
 	LocalizeControl(_attachToPreviousBtn, pSS, AP_STRING_ID_DLG_Lists_Resume);
 
+	LocalizeControl([_mainTab tabViewItemAtIndex:0], pSS, AP_STRING_ID_DLG_Lists_PageProperties);
+	LocalizeControl([_mainTab tabViewItemAtIndex:1], pSS, AP_STRING_ID_DLG_Lists_PageFolding);
+	
+	LocalizeControl(_noFoldingBtn, pSS, AP_STRING_ID_DLG_Lists_FoldingLevelexp);
+	LocalizeControl(_noFoldingBtn, pSS, AP_STRING_ID_DLG_Lists_FoldingLevel0);
+	LocalizeControl(_foldLevel1Btn, pSS, AP_STRING_ID_DLG_Lists_FoldingLevel1);
+	LocalizeControl(_foldLevel2Btn, pSS, AP_STRING_ID_DLG_Lists_FoldingLevel2);
+	LocalizeControl(_foldLevel3Btn, pSS, AP_STRING_ID_DLG_Lists_FoldingLevel3);
+	LocalizeControl(_foldLevel4Btn, pSS, AP_STRING_ID_DLG_Lists_FoldingLevel4);
 }
 
 - (XAP_CocoaNSView*)preview
@@ -772,11 +800,22 @@ void AP_CocoaDialog_Lists::_gatherData(void)
 	}
 }
 
+- (void)selectFolding:(int)folding
+{
+	[_foldingMatrix selectCellWithTag:folding];
+}
+
+
+// return the tab that is selected.
+- (int)selectedTab
+{
+	return [_mainTab indexOfTabViewItem: [_mainTab selectedTabViewItem]];
+}
 
 - (IBAction)applyAction:(id)sender
 {
 	_xap->applyClicked();
-	[NSApp stopModal];
+	// [NSApp stopModal];
 }
 
 - (IBAction)cancelAction:(id)sender
@@ -856,6 +895,15 @@ void AP_CocoaDialog_Lists::_gatherData(void)
 	_xap->previewExposed();
 }
 
+
+- (IBAction)foldingChanged:(id)sender
+{
+	NSMatrix *m = sender;
+	
+	_xap->_foldingChanged([m selectedRow]);
+}
+
+
 @end
 
 
