@@ -57,6 +57,7 @@
 #define AP_CLIPBOARD_IMAGE_WMF                  "image/x-wmf"
 #define AP_CLIPBOARD_IMAGE_SVG                  "image/svg"
 #define AP_CLIPBOARD_IMAGE_SVG_XML              "image/svg+xml"
+#define AP_CLIPBOARD_IMAGE_GOChart              "application/x-goffice-graph"
 
 // Text: cut and paste
 #define AP_CLIPBOARD_TEXT_UTF8_STRING           "UTF8_STRING"
@@ -76,6 +77,7 @@ static const char * htmlszFormatsAccepted[] = {
   0 } ;
 
 static const char * imgszFormatsAccepted[] = {
+  AP_CLIPBOARD_IMAGE_GOChart,
   AP_CLIPBOARD_IMAGE_PNG,
   AP_CLIPBOARD_IMAGE_JPEG,
   AP_CLIPBOARD_IMAGE_TIFF,
@@ -103,6 +105,7 @@ AP_UnixClipboard::AP_UnixClipboard(AP_UnixApp * pApp)
   AddFmt(AP_CLIPBOARD_APPLICATION_RTF);
   
   // image types
+  AddFmt ( AP_CLIPBOARD_IMAGE_GOChart ) ;
   AddFmt ( AP_CLIPBOARD_IMAGE_PNG ) ;
   AddFmt ( AP_CLIPBOARD_IMAGE_JPEG ) ;
   AddFmt ( AP_CLIPBOARD_IMAGE_TIFF ) ;
@@ -245,5 +248,8 @@ bool AP_UnixClipboard::isImageTag ( const char * tag )
 
   if ( !strncmp ( tag, "image/", 6 ) )
     return true ;
+
+  if ( !strncmp ( tag, "application/x-goffice", 21 ) )
+    return true ;
   return false ;
 }
