@@ -17,22 +17,20 @@
  * 02111-1307, USA.
  */
 
-#undef GTK_DISABLE_DEPRECATED
-
 #include <stdlib.h>
 #include <glade/glade.h>
+#include <gdk/gdk.h>
 #include "ut_locale.h"
 
 #include "ut_string.h"
 #include "ut_assert.h"
 #include "ut_debugmsg.h"
+#include "ut_unixMisc.h"
 
 // This header defines some functions for Unix dialogs,
 // like centering them, measuring them, etc.
 #include "xap_UnixDialogHelper.h"
 
-#include "xap_UnixGtkColorPicker.h"
-
 #include "xap_App.h"
 #include "xap_UnixApp.h"
 #include "xap_Frame.h"
@@ -49,7 +47,7 @@ static void s_apply_changes(GtkWidget *widget, gpointer data )
 {
 	AP_UnixDialog_FormatFrame * dlg = reinterpret_cast<AP_UnixDialog_FormatFrame *>(data);
 	UT_return_if_fail(widget && dlg);
-	dlg->applyChanges();
+	dlg->event_ApplyToChanged();
 }
 
 static void s_close_window(GtkWidget *widget, gpointer data )
@@ -100,17 +98,6 @@ static void s_WrapButton(GtkWidget *widget, gpointer data )
 	dlg->setWrapping(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget)));
 }
 
-static void s_border_color(GtkWidget *widget, gpointer data )
-{
-	AP_UnixDialog_FormatFrame * dlg = static_cast<AP_UnixDialog_FormatFrame *>(data);
-	UT_return_if_fail(widget && dlg);
-	
-	guint8 r, g, b, a;
-	gtk_color_picker_get_i8 (GTK_COLOR_PICKER(widget), &r, &g, &b, &a);
-	dlg->setBorderColor(UT_RGBColor(r,g,b));
-	dlg->event_previewExposed();
-}
-
 static void s_border_thickness(GtkWidget *widget, gpointer data )
 {
 	AP_UnixDialog_FormatFrame * dlg = static_cast<AP_UnixDialog_FormatFrame *>(data);
@@ -118,17 +105,6 @@ static void s_border_thickness(GtkWidget *widget, gpointer data )
 	dlg->event_BorderThicknessChanged();
 }
 
-static void s_background_color(GtkWidget *widget, gpointer data)
-{
-	AP_UnixDialog_FormatFrame * dlg = static_cast<AP_UnixDialog_FormatFrame *>(data);
-	UT_return_if_fail(widget && dlg);
-	
-	guint8 r, g, b, a;
-	gtk_color_picker_get_i8 (GTK_COLOR_PICKER(widget), &r, &g, &b, &a);
-	dlg->setBGColor(UT_RGBColor(r,g,b));
-	dlg->event_previewExposed();
-}
-
 static gboolean s_preview_exposed(GtkWidget * widget, gpointer /* data */, AP_UnixDialog_FormatFrame * dlg)
 {
 	UT_return_val_if_fail(widget && dlg, FALSE);
@@ -152,6 +128,92 @@ static gboolean s_remove_image(GtkWidget *widget, gpointer data)
 	return FALSE;
 }
 
+/*!
+* Intercept clicks on the color button and show an own GtkColorSelectionDialog
+* with palette enabled.
+*/
+static gboolean 
+AP_UnixDialog_FormatFrame__onBorderColorClicked (GtkWidget 		*button,
+												 GdkEventButton *event,
+												 gpointer 		data)
+{
+	// only handle left clicks
+	if (event->button != 1) {
+		return FALSE;
+	}
+
+	AP_UnixDialog_FormatFrame *dlg = static_cast<AP_UnixDialog_FormatFrame *>(data);
+	UT_return_val_if_fail (button && dlg, FALSE);
+
+	GtkWidget *colordlg = gtk_color_selection_dialog_new  ("");
+	gtk_window_set_transient_for (GTK_WINDOW (colordlg), GTK_WINDOW (dlg->getWindow ()));
+	GtkColorSelection *colorsel = GTK_COLOR_SELECTION ((GTK_COLOR_SELECTION_DIALOG (colordlg))->colorsel);
+	gtk_color_selection_set_has_palette (colorsel, TRUE);
+	
+	gint result = gtk_dialog_run (GTK_DIALOG (colordlg));
+	if (result == GTK_RESPONSE_OK) {
+		
+		// update button
+		GtkColorButton *colorbtn = GTK_COLOR_BUTTON (button);
+		GdkColor color;
+		gtk_color_selection_get_current_color (colorsel, &color);
+		gtk_color_button_set_color (colorbtn, &color);
+
+		// update dialog
+		UT_RGBColor* rgb = UT_UnixGdkColorToRGBColor (color);
+		dlg->setBorderColor (*rgb);
+		DELETEP (rgb);
+		dlg->event_previewExposed ();
+	}
+		
+	// do not propagate further
+	gtk_widget_destroy (colordlg);
+	return TRUE;
+}
+
+/*!
+* Intercept clicks on the color button and show an own GtkColorSelectionDialog
+* with palette enabled.
+*/
+static gboolean 
+AP_UnixDialog_FormatFrame__onBackgroundColorClicked (GtkWidget 		*button,
+													 GdkEventButton *event,
+													 gpointer 		data)
+{
+	// only handle left clicks
+	if (event->button != 1) {
+		return FALSE;
+	}
+
+	AP_UnixDialog_FormatFrame *dlg = static_cast<AP_UnixDialog_FormatFrame *>(data);
+	UT_return_val_if_fail (button && dlg, FALSE);
+
+	GtkWidget *colordlg = gtk_color_selection_dialog_new  ("");
+	gtk_window_set_transient_for (GTK_WINDOW (colordlg), GTK_WINDOW (dlg->getWindow ()));
+	GtkColorSelection *colorsel = GTK_COLOR_SELECTION ((GTK_COLOR_SELECTION_DIALOG (colordlg))->colorsel);
+	gtk_color_selection_set_has_palette (colorsel, TRUE);
+	
+	gint result = gtk_dialog_run (GTK_DIALOG (colordlg));
+	if (result == GTK_RESPONSE_OK) {
+		
+		// update button
+		GtkColorButton *colorbtn = GTK_COLOR_BUTTON (button);
+		GdkColor color;
+		gtk_color_selection_get_current_color (colorsel, &color);
+		gtk_color_button_set_color (colorbtn, &color);
+
+		// update dialog
+		UT_RGBColor* rgb = UT_UnixGdkColorToRGBColor (color);
+		dlg->setBGColor (*rgb);
+		DELETEP (rgb);
+		dlg->event_previewExposed ();
+	}
+		
+	// do not propagate further
+	gtk_widget_destroy (colordlg);
+	return TRUE;
+}
+
 /*****************************************************************/
 
 #define	WIDGET_ID_TAG_KEY "id"
@@ -184,6 +246,9 @@ AP_UnixDialog_FormatFrame::AP_UnixDialog_FormatFrame(XAP_DialogFactory * pDlgFac
 	m_wBorderThickness = NULL;
 	m_iBorderThicknessConnect = 0;
 	m_wWrapButton = NULL;
+	m_wPosParagraph =  NULL;
+	m_wPosColumn = NULL;
+	m_wPosPage = NULL;
 //
 // These are hardwired into the GUI.
 //
@@ -309,6 +374,19 @@ void AP_UnixDialog_FormatFrame::event_BorderThicknessChanged(void)
 
 void AP_UnixDialog_FormatFrame::event_ApplyToChanged(void)
 {
+        if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(m_wPosParagraph )))
+        {
+	     setPositionMode(FL_FRAME_POSITIONED_TO_BLOCK);  
+	}
+	else if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(m_wPosColumn )))
+        {
+	     setPositionMode(FL_FRAME_POSITIONED_TO_COLUMN);  
+	}
+	else if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(m_wPosPage )))
+        {
+	     setPositionMode(FL_FRAME_POSITIONED_TO_PAGE);  
+	}
+        applyChanges();
 }
 
 void AP_UnixDialog_FormatFrame::destroy(void)
@@ -353,6 +431,18 @@ void AP_UnixDialog_FormatFrame::notifyActiveFrame(XAP_Frame *pFrame)
 			setWrapping(false);
 		}
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_wWrapButton),getWrapping());
+		if(positionMode() == FL_FRAME_POSITIONED_TO_BLOCK)
+		{
+		     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON( m_wPosParagraph),TRUE);
+		}
+		else if(positionMode() == FL_FRAME_POSITIONED_TO_COLUMN)
+		{
+		     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_wPosColumn),TRUE);
+		} 
+		else if(positionMode() == FL_FRAME_POSITIONED_TO_PAGE)
+		{
+		     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_wPosPage),TRUE);
+		} 
 	}
 }
 
@@ -420,7 +510,10 @@ GtkWidget * AP_UnixDialog_FormatFrame::_constructWindow(void)
 	localizeButton(glade_xml_get_widget(xml, "rbSetToParagraph"), pSS, AP_STRING_ID_DLG_FormatFrame_SetToParagraph);
 	localizeButton(glade_xml_get_widget(xml, "rbSetToColumn"), pSS, AP_STRING_ID_DLG_FormatFrame_SetToColumn);
 	localizeButton(glade_xml_get_widget(xml, "rbSetToPage"), pSS, AP_STRING_ID_DLG_FormatFrame_SetToPage);
-	
+	m_wPosParagraph = glade_xml_get_widget(xml, "rbSetToParagraph");
+	m_wPosColumn = glade_xml_get_widget(xml, "rbSetToColumn");
+	m_wPosPage = glade_xml_get_widget(xml, "rbSetToPage");
+
 //  Button and label for text wrapping
 
 	m_wWrapButton = glade_xml_get_widget(xml, "btTextWrapState");
@@ -439,17 +532,9 @@ GtkWidget * AP_UnixDialog_FormatFrame::_constructWindow(void)
 	
 	localizeLabelMarkup(glade_xml_get_widget(xml, "lbPreview"), pSS, AP_STRING_ID_DLG_FormatFrame_Preview);
 	
-	// add the custom color picker buttons to the dialog
-	m_wBorderColorButton = gtk_color_picker_new();
-	gtk_widget_show(m_wBorderColorButton);
-	gtk_table_attach(GTK_TABLE (glade_xml_get_widget(xml, "tbBorder")), m_wBorderColorButton, 3, 4, 1, 2,
-                    (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 
-					0, 0);
-					
-	// add the custom color picker buttons to the dialog
-	m_wBackgroundColorButton = gtk_color_picker_new();
-	gtk_widget_show(m_wBackgroundColorButton);
-	gtk_box_pack_start(GTK_BOX (glade_xml_get_widget(xml, "hbBackgroundColor")), m_wBackgroundColorButton, TRUE, TRUE, 0);
+	m_wBorderColorButton = glade_xml_get_widget(xml, "cbtBorderColorButton");
+	m_wBackgroundColorButton = glade_xml_get_widget(xml, "cbtBackgroundColorButton");
+
 //
 // Now the Border Thickness Option menu
 // 
@@ -534,13 +619,13 @@ void AP_UnixDialog_FormatFrame::_connectSignals(void)
 							reinterpret_cast<gpointer>(this));		   
 						   
 	g_signal_connect(G_OBJECT(m_wBorderColorButton),
-							"color_set",
-							G_CALLBACK(s_border_color),
+							"button-release-event",
+							G_CALLBACK(AP_UnixDialog_FormatFrame__onBorderColorClicked),
 							reinterpret_cast<gpointer>(this));
 
 	g_signal_connect(G_OBJECT(m_wBackgroundColorButton),
-							"color_set",
-							G_CALLBACK(s_background_color),
+							"button-release-event",
+							G_CALLBACK(AP_UnixDialog_FormatFrame__onBackgroundColorClicked),
 							reinterpret_cast<gpointer>(this));	   
 
 	m_iBorderThicknessConnect = g_signal_connect(G_OBJECT(m_wBorderThickness),
