@@ -20,6 +20,10 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
+#include <ctype.h>
+
+#include "ap_Features.h"
+
 #include "ut_assert.h"
 #include "ut_string.h"
 #include "ut_units.h"
@@ -38,6 +42,8 @@
 #include "ap_Strings.h"
 #include "ap_TopRuler.h"		// for AP_TopRulerInfo
 
+
+
 AP_Dialog_Tab::AP_Dialog_Tab(XAP_DialogFactory * pDlgFactory, XAP_Dialog_Id id)
 	: XAP_Dialog_NonPersistent(pDlgFactory,id, "interface/dialogtabs"),
 	  m_answer(a_OK), 
@@ -71,11 +77,10 @@ AP_Dialog_Tab::tAnswer AP_Dialog_Tab::getAnswer(void) const
 
 void AP_Dialog_Tab::_storeWindowData()
 {
-	UT_ASSERT(m_pFrame); // needs to be set from runModal for some of the event_'s to work
+	UT_return_if_fail (m_pFrame); // needs to be set from runModal for some of the event_'s to work
 
 	FV_View *pView = (FV_View *)m_pFrame->getCurrentView();
-
-	UT_ASSERT(m_pCallbackFn);
+	UT_return_if_fail (pView && m_pCallbackFn);
 
 	(*m_pCallbackFn)(this, pView, m_pszTabStops, _gatherDefaultTabStop(), m_closure);
 }
@@ -88,10 +93,10 @@ void AP_Dialog_Tab::_populateWindowData(void)
 	else
 		m_dim = DIM_IN;
 
-	UT_ASSERT(m_pFrame); // needs to be set from runModal for some of the event_'s to work
+	UT_return_if_fail (m_pFrame); // needs to be set from runModal for some of the event_'s to work
 
 	FV_View *pView = (FV_View *)m_pFrame->getCurrentView();
-
+	UT_return_if_fail (pView);
 
 	// get the info used in the top ruler
 	AP_TopRulerInfo rulerInfo;
@@ -115,7 +120,7 @@ void AP_Dialog_Tab::_populateWindowData(void)
 	
 		// create new tab info
 		pTabInfo = new fl_TabStop();
-		UT_ASSERT(pTabInfo);
+		UT_return_if_fail (pTabInfo);
 
 
 		(*rulerInfo.m_pfnEnumTabStops)( rulerInfo.m_pVoidEnumTabStopsData,
@@ -184,7 +189,7 @@ void AP_Dialog_Tab::_event_TabSelected( UT_sint32 index )
 
 	if(index >= 0)
 	{
-		UT_ASSERT(index < (UT_sint32)m_tabInfo.getItemCount());
+		UT_return_if_fail (index < (UT_sint32)m_tabInfo.getItemCount());
 
 		fl_TabStop *pTabInfo = (fl_TabStop *)m_tabInfo.getNthItem(index);
 
@@ -197,7 +202,7 @@ void AP_Dialog_Tab::_event_TabSelected( UT_sint32 index )
 		_setLeader( pTabInfo->getLeader() );
 
 		_setTabEdit( _getTabDimensionString(index) );
-		
+
 		// something changed...
 		_event_somethingChanged();
 	}
@@ -207,7 +212,13 @@ void AP_Dialog_Tab::_event_Set(void)
 {
 	UT_String buffer;
 
-	buildTab(buffer);
+	// check the validity of the input
+	bool res = buildTab(buffer);
+	if (!res)
+	{
+		// TODO: add a message box here to inform our user - MARCM
+		return;
+	}
 
 	UT_DEBUGMSG(("DOM: %s\n", buffer.c_str()));
 
@@ -230,7 +241,7 @@ void AP_Dialog_Tab::_event_Set(void)
 	for (  i = 0; i < m_tabInfo.getItemCount(); i++ )
 	{
 		fl_TabStop *pTabInfo = (fl_TabStop *)m_tabInfo.getNthItem(i);
-		UT_ASSERT(pTabInfo);
+		UT_return_if_fail (pTabInfo);
 
 		// if we have a tab at that unit
 		if ( memcmp(cbuffer, _getTabString(pTabInfo), Dimension_size) == 0 )
@@ -256,20 +267,21 @@ void AP_Dialog_Tab::_event_Set(void)
 	delete [] m_pszTabStops;
 	m_pszTabStops = p_temp;
 
-	UT_ASSERT(m_pFrame); // needs to be set from runModal for some of the event_'s to work
+	UT_return_if_fail (m_pFrame); // needs to be set from runModal for some of the event_'s to work
 
 	FV_View *pView = static_cast<FV_View *>(m_pFrame->getCurrentView());
-
+	UT_return_if_fail(pView);
+	
 	buildTabStops(pView->getGraphics(), m_pszTabStops, m_tabInfo);
 
 	_setTabList(m_tabInfo.getItemCount());
 
-	// Select the new or changed tab in the lis.
+	// Select the new or changed tab in the list.
 
 	for (i = 0; i < m_tabInfo.getItemCount(); i++ )
 	{
-		fl_TabStop *pTabInfo = static_cast<fl_TabStop *>(m_tabInfo.getNthItem(i));
-		UT_ASSERT(pTabInfo);
+		fl_TabStop *pTabInfo = m_tabInfo.getNthItem(i);
+		UT_return_if_fail (pTabInfo);
 
 		// if we have a tab at that unit
 		if ( memcmp(cbuffer, _getTabString(pTabInfo), Dimension_size) == 0 )
@@ -285,6 +297,104 @@ void AP_Dialog_Tab::_event_Set(void)
 
 }
 
+/*!
+* Update the currently selected tab's properties.
+* Ripped off from _event_Set(). This method does auto-apply.
+*/
+void AP_Dialog_Tab::_event_Update(void)
+{
+	fl_TabStop *pTabInfo = NULL;
+
+	// check the validity of the input
+	UT_String buffer;
+	bool res = buildTab(buffer);
+	if (!res)
+	{
+		// TODO: add a message box here to inform our user - MARCM
+		return;
+	}
+
+
+	// delete tab
+	UT_uint32 ndx = _gatherSelectTab();
+	pTabInfo = m_tabInfo.getNthItem(ndx);
+	_deleteTabFromTabString(pTabInfo);
+	m_tabInfo.deleteNthItem(ndx);
+
+
+	// re-add
+	const char *cbuffer = buffer.c_str();
+	int Dimension_size = 0;
+	while(cbuffer[Dimension_size] != 0)
+	{
+
+		if(cbuffer[Dimension_size] == '/')
+		{
+			Dimension_size--;
+			break;
+		}
+
+		Dimension_size++;
+	}
+
+	// do we have the tab already.
+	UT_uint32 i;
+	for (i = 0; i < m_tabInfo.getItemCount(); i++ )
+	{
+		pTabInfo = (fl_TabStop *)m_tabInfo.getNthItem(i);
+		UT_return_if_fail (pTabInfo);
+
+		// if we have a tab at that unit
+		if ( memcmp(cbuffer, _getTabString(pTabInfo), Dimension_size) == 0 )
+		{
+			// Delete the tab.
+			_deleteTabFromTabString(pTabInfo);
+			break;
+		}
+	}
+
+	// Add tab to list.
+	int NewOffset = strlen(m_pszTabStops);
+	char *p_temp = new char[NewOffset + 1 + strlen(cbuffer) + 1];
+	strcpy(p_temp, m_pszTabStops);
+	if(m_pszTabStops[0] != 0)
+	{
+		strcat(p_temp, ",");
+	}
+	strcat(p_temp, cbuffer);
+	delete [] m_pszTabStops;
+	m_pszTabStops = p_temp;
+
+	UT_return_if_fail (m_pFrame); // needs to be set from runModal for some of the event_'s to work
+
+	FV_View *pView = static_cast<FV_View *>(m_pFrame->getCurrentView());
+	UT_return_if_fail(pView);
+	
+	buildTabStops(pView->getGraphics(), m_pszTabStops, m_tabInfo);
+
+	_setTabList(m_tabInfo.getItemCount());
+
+	// Select the new or changed tab in the list.
+
+	for (i = 0; i < m_tabInfo.getItemCount(); i++ )
+	{
+		fl_TabStop *pTabInfo = m_tabInfo.getNthItem(i);
+		UT_return_if_fail (pTabInfo);
+
+		// if we have a tab at that unit
+		if ( memcmp(cbuffer, _getTabString(pTabInfo), Dimension_size) == 0 )
+		{
+			_setSelectTab(i);
+			_setTabEdit( _getTabDimensionString(i) );
+			break;
+		}
+	}
+
+	// something changed...
+	_event_somethingChanged();
+	_storeWindowData ();
+}
+
 void AP_Dialog_Tab::_event_Clear(void)
 {
 	UT_DEBUGMSG(("AP_Dialog_Tab::_event_Clear\n"));
@@ -295,7 +405,7 @@ void AP_Dialog_Tab::_event_Clear(void)
 	{
 		UT_return_if_fail(index < static_cast<UT_sint32>(m_tabInfo.getItemCount()));
 
-		_deleteTabFromTabString(static_cast<fl_TabStop *>(m_tabInfo.getNthItem(index)));
+		_deleteTabFromTabString(m_tabInfo.getNthItem(index));
 
 		UT_return_if_fail(m_pFrame); // needs to be set from runModal for some of the event_'s to work
 
@@ -366,7 +476,7 @@ void AP_Dialog_Tab::_event_ClearAll(void)
 		break;
 
 	default:
-		UT_ASSERT(UT_NOT_IMPLEMENTED);
+		UT_ASSERT_HARMLESS(UT_NOT_IMPLEMENTED);
 		ch = 'L';
 		break;
 	}
@@ -400,7 +510,7 @@ void AP_Dialog_Tab::_event_ClearAll(void)
 		break;
 
 	default:
-		UT_ASSERT(UT_NOT_IMPLEMENTED);
+		UT_ASSERT_HARMLESS(UT_NOT_IMPLEMENTED);
 		a = FL_TAB_LEFT;
 	}
 	return a;
@@ -414,14 +524,20 @@ void AP_Dialog_Tab::clearList()
 }
 
 
-void AP_Dialog_Tab::buildTab( UT_String & buffer )
+bool AP_Dialog_Tab::buildTab( UT_String & buffer )
 {
 	// get current value from member
 	const XML_Char* szOld = _gatherTabEdit();
-	const XML_Char* szNew = UT_reformatDimensionString(m_dim, szOld); 
+	bool res = UT_isValidDimensionString(szOld, MAX_TAB_LENGTH);
+	if (res)
+	{
+		const XML_Char* szNew = UT_reformatDimensionString(m_dim, szOld); 
 
-	UT_String_sprintf( buffer, "%s/%c%c", szNew, AlignmentToChar(_gatherAlignment()),
-		 				(static_cast<char>(_gatherLeader()))+'0');
+		UT_String_sprintf( buffer, "%s/%c%c", szNew, AlignmentToChar(_gatherAlignment()),
+		 					(static_cast<char>(_gatherLeader()))+'0');
+	}
+	
+	return res;
 }
 
 void AP_Dialog_Tab::_event_somethingChanged()
@@ -447,8 +563,8 @@ void AP_Dialog_Tab::_event_somethingChanged()
 
 	for ( UT_uint32 i = 0; i < m_tabInfo.getItemCount(); i++ )
 	{
-		fl_TabStop *pTabInfo = static_cast<fl_TabStop *>(m_tabInfo.getNthItem(i));
-		UT_ASSERT(pTabInfo);
+		fl_TabStop *pTabInfo = m_tabInfo.getNthItem(i);
+		UT_return_if_fail (pTabInfo);
 
 		// if we have a tab at that unit
 		if ( !strcmp(cbuffer, _getTabString(pTabInfo)) )
@@ -476,9 +592,9 @@ void AP_Dialog_Tab::_event_somethingChanged()
 char *AP_Dialog_Tab::_getTabDimensionString(UT_uint32 tabIndex)
 {
 
-	UT_ASSERT(tabIndex < m_tabInfo.getItemCount());
+	UT_return_val_if_fail (tabIndex < m_tabInfo.getItemCount(), NULL);
 
-	fl_TabStop *pTabInfo = static_cast<fl_TabStop *>(m_tabInfo.getNthItem(tabIndex));
+	fl_TabStop *pTabInfo = m_tabInfo.getNthItem(tabIndex);
 
 	const char* pStart = &m_pszTabStops[pTabInfo->getOffset()];
 	const char* pEnd = pStart;
@@ -488,7 +604,7 @@ char *AP_Dialog_Tab::_getTabDimensionString(UT_uint32 tabIndex)
 	}
 
 	UT_uint32 iLen = pEnd - pStart;
-	UT_ASSERT(iLen<20);
+	UT_return_val_if_fail (iLen<20, NULL);
 
 	strncpy(buf, pStart, iLen);
 	buf[iLen]=0;
@@ -506,7 +622,6 @@ char *AP_Dialog_Tab::_getTabString(fl_TabStop *pTabInfo)
 	}
 
 	UT_uint32 iLen = pEnd - pStart;
-	UT_ASSERT(iLen<20);
 
 	strncpy(buf, pStart, iLen);
 	buf[iLen]=0;
@@ -565,8 +680,10 @@ void AP_Dialog_Tab::_deleteTabFromTabString(fl_TabStop *pTabInfo)
 
 void AP_Dialog_Tab::_doSpin(tControl id, UT_sint32 amt)
 {
+	UT_DEBUGMSG (("ROB: _doSpin %d, %d\n", id, amt));
+
   //	UT_ASSERT(amt); // zero makes no sense
-	UT_ASSERT(id = id_SPIN_DEFAULT_TAB_STOP);
+	UT_return_if_fail (id == id_SPIN_DEFAULT_TAB_STOP);
 	if(amt == 0 )
 	{
 	        UT_DEBUGMSG(("AMOUNT = 0 amt = %d \n",amt));
@@ -607,7 +724,7 @@ void AP_Dialog_Tab::_doSpin(tControl id, UT_sint32 amt)
 		break;
 	default:
 
-		UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
+		UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
 		break;
 	}
 
@@ -641,8 +758,10 @@ void AP_Dialog_Tab::_doSpin(tControl id, UT_sint32 amt)
 //      limit and make sure the settings are correct.
 void AP_Dialog_Tab::_doSpinValue(tControl id, double value)
 {
+	UT_DEBUGMSG (("ROB: _doSpinValue %d, %f\n", id, value));
+
   //	UT_ASSERT(amt); // zero makes no sense
-	UT_ASSERT(id = id_SPIN_DEFAULT_TAB_STOP);
+	UT_return_if_fail (id == id_SPIN_DEFAULT_TAB_STOP);
 
 	double d = value;
 
@@ -678,7 +797,7 @@ void AP_Dialog_Tab::_doSpinValue(tControl id, double value)
 		break;
 	default:
 
-		UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
+		UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
 		break;
 	}
 
@@ -707,4 +826,3 @@ void AP_Dialog_Tab::_doSpinValue(tControl id, double value)
 
 	_setDefaultTabStop(szNew);
 }
-
