@@ -2387,21 +2387,24 @@ bool IE_Imp_TableHelper::tdEnd(void)
 	m_current->m_tzone = m_tzone;
 	UT_GenericVector<CellHelper *>* pVecCells = NULL;
 	pCell = NULL;
-	if(pfsThis == NULL)
+	if(true)
 		{
 			if(m_tzone == tz_head)
 				{
-					pCell = getCellAtRowCol(m_thead,m_row_next,m_col_next+colspan);
+					if(pfsThis == NULL)
+						pCell = getCellAtRowCol(m_thead,m_row_next,m_col_next+colspan);
 					pVecCells = & m_thead;
 				}
 			else if(m_tzone == tz_foot)
 				{
-					pCell = getCellAtRowCol(m_tfoot,m_row_next,m_col_next+colspan);
+					if(pfsThis == NULL)
+						pCell = getCellAtRowCol(m_tfoot,m_row_next,m_col_next+colspan);
 					pVecCells = & m_tfoot;
 				}
 			else if(m_tzone == tz_body)
 				{
-					pCell = getCellAtRowCol(m_tbody,m_row_next,m_col_next+colspan);
+					if(pfsThis == NULL)
+						pCell = getCellAtRowCol(m_tbody,m_row_next,m_col_next+colspan);
 					pVecCells = & m_tbody;
 				}
 		}
@@ -2530,6 +2533,18 @@ bool IE_Imp_TableHelper::Inline (const UT_UCSChar * ucs4_str, UT_sint32 length)
 		{
 			pf = static_cast<pf_Frag *>(m_pfsInsertionPoint);
 		}
+#if DEBUG
+#if 0
+	UT_uint32 ii = 0;
+	UT_String sStr;
+	for(ii=0; ii<(length);ii++)
+	{
+		sStr += static_cast<const char>(ucs4_str[ii]);
+	}
+	UT_DEBUGMSG(("Append span in cell %s \n",sStr.c_str()));
+#endif
+#endif
+
 	UT_DEBUGMSG(("Insert Text of length %d in cell \n",length));
 	getDoc()->insertSpanBeforeFrag(pf, ucs4_str, length);
 	return true;
