@@ -287,7 +287,6 @@
 #include "px_CR_Object.h"
 #include "px_CR_Span.h"
 #include "px_CR_Strux.h"
-#include "xap_App.h"
 
 /*****************************************************************/
 /*****************************************************************/
@@ -335,7 +334,7 @@ int abi_plugin_unregister (XAP_ModuleInfo * mi)
 	mi->author = 0;
 	mi->usage = 0;
 
-	UT_ASSERT (m_sniffer);
+	UT_return_val_if_fail( m_sniffer, 0 );
 
 	IE_Exp::unregisterExporter (m_sniffer);
 	if (!m_sniffer->unref())
@@ -350,7 +349,7 @@ ABI_FAR_CALL
 int abi_plugin_supports_version (UT_uint32 major, UT_uint32 minor, 
 								 UT_uint32 release)
 {
-       return isCurrentAbiVersion (major, minor, release) ? 1 : 0;
+  return 1;
 }
 
 #endif
@@ -358,6 +357,21 @@ int abi_plugin_supports_version (UT_uint32 major, UT_uint32 minor,
 /*****************************************************************/
 /*****************************************************************/
 
+IE_Exp_MsWord_97_Sniffer::IE_Exp_MsWord_97_Sniffer ()
+	: IE_ExpSniffer(IE_IMPEXPNAME_MSWORD97)
+{
+	// 
+}
+
+UT_Confidence_t IE_Exp_MsWord_97_Sniffer::supportsMIME (const char * szMIME)
+{
+	if (UT_strcmp (szMIME, IE_MIME_MSWord) == 0)
+		{
+			return UT_CONFIDENCE_SOSO;
+		}
+	return UT_CONFIDENCE_ZILCH;
+}
+
 bool IE_Exp_MsWord_97_Sniffer::recognizeSuffix(const char * szSuffix)
 {
 	return (!UT_stricmp(szSuffix,".doc") || !UT_stricmp(szSuffix, ".dot"));
@@ -489,7 +503,7 @@ UT_Error IE_Exp_MsWord_97::_writeDocument(void)
 
 bool IE_Exp_MsWord_97::_openFile(const char * szFileName)
 {
-	UT_ASSERT(szFileName);
+	UT_return_val_if_fail(szFileName, false);
 
 	m_pExporter = wvExporter_create(szFileName);
 	if(!m_pExporter)
@@ -518,20 +532,19 @@ bool IE_Exp_MsWord_97::_openFile(const char * szFileName)
 
 UT_uint32 IE_Exp_MsWord_97::_writeBytes(const UT_Byte * pBytes, UT_uint32 length)
 {
-	UT_ASSERT(pBytes);
-	UT_ASSERT(length);
-
+	UT_return_val_if_fail(pBytes && length, UT_ERROR);
 	UT_DEBUGMSG(("Writing %s", pBytes));
 
 	return wvExporter_writeBytes(m_pExporter, sizeof(UT_Byte), 
-				     length, (void*)pBytes);
+				     length, const_cast<void*>(static_cast<const void*>(pBytes)));
 }
 
 bool IE_Exp_MsWord_97::_writeBytes(const UT_Byte * pBytes)
 {
-	UT_ASSERT(pBytes);
-	UT_uint32 length = (UT_uint32)strlen((const char *)pBytes);
-	UT_ASSERT(length);
+	UT_return_val_if_fail(pBytes, false);
+	
+	UT_uint32 length = static_cast<UT_uint32>(strlen(reinterpret_cast<const char *>(pBytes)));
+	UT_return_val_if_fail(length, false);
 
 	return (_writeBytes(pBytes, length) == length);
 }
@@ -556,7 +569,7 @@ void IE_Exp_MsWord_97::_abortFile(void)
 
 void IE_Exp_MsWord_97::write(const char * sz)
 {
-	write(sz, (UT_uint32)strlen(sz));
+	write(sz, static_cast<UT_uint32>(strlen(sz)));
 }
 
 void IE_Exp_MsWord_97::write(const char * sz, UT_uint32 length)
@@ -564,7 +577,7 @@ void IE_Exp_MsWord_97::write(const char * sz, UT_uint32 length)
 	if(m_error)
 		return;
 
-	m_error |= (_writeBytes ((UT_Byte *)sz, length) != length);
+	m_error |= (_writeBytes (reinterpret_cast<const UT_Byte *>(sz), length) != length);
 }
 
 /********************************************************/
@@ -618,8 +631,13 @@ bool s_MsWord_97_Listener::populate(PL_StruxFmtHandle /*sfh*/,
 				
 				return true;
 
+				// todo: support these
+			case PTO_Hyperlink:
+			case PTO_Bookmark:
+			  return true;
+
 			default:
-				UT_ASSERT(0);
+				UT_ASSERT_HARMLESS(0);
 				return false;
 			}
 		}
@@ -628,7 +646,7 @@ bool s_MsWord_97_Listener::populate(PL_StruxFmtHandle /*sfh*/,
 		return true;
 		
 	default:
-		UT_ASSERT(0);
+		UT_ASSERT_HARMLESS(0);
 		return false;
 	}
 }
@@ -637,7 +655,7 @@ bool s_MsWord_97_Listener::populateStrux(PL_StruxDocHandle /*sdh*/,
 										   const PX_ChangeRecord * pcr,
 										   PL_StruxFmtHandle * psfh)
 {
-	UT_ASSERT(pcr->getType() == PX_ChangeRecord::PXT_InsertStrux);
+	UT_return_val_if_fail(pcr->getType() == PX_ChangeRecord::PXT_InsertStrux, false);
 	const PX_ChangeRecord_Strux * pcrx = static_cast<const PX_ChangeRecord_Strux *> (pcr);
 	*psfh = 0;							// we don't need it.
 
@@ -673,7 +691,7 @@ bool s_MsWord_97_Listener::populateStrux(PL_StruxDocHandle /*sdh*/,
 		}
 
 	default:
-		UT_ASSERT(0);
+		UT_ASSERT_HARMLESS(0);
 		return false;
 	}
 }
@@ -681,7 +699,7 @@ bool s_MsWord_97_Listener::populateStrux(PL_StruxDocHandle /*sdh*/,
 bool s_MsWord_97_Listener::change(PL_StruxFmtHandle /*sfh*/,
 									const PX_ChangeRecord * /*pcr*/)
 {
-	UT_ASSERT(0);						// this function is not used.
+	UT_ASSERT_HARMLESS(0);						// this function is not used.
 	return false;
 }
 
@@ -693,13 +711,13 @@ bool s_MsWord_97_Listener::insertStrux(PL_StruxFmtHandle /*sfh*/,
 																	  PL_ListenerId /* lid */,
 																	  PL_StruxFmtHandle /* sfhNew */))
 {
-	UT_ASSERT(0);						// this function is not used.
+	UT_ASSERT_HARMLESS(0);						// this function is not used.
 	return false;
 }
 
 bool s_MsWord_97_Listener::signal(UT_uint32 /* iSignal */)
 {
-	UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
+	UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
 	return false;
 }
 
@@ -796,7 +814,7 @@ void s_MsWord_97_Listener::_convertColor (UT_sint32 * mscol, const char * szFrom
 	// msword 97's (tiny) 16-color palette
 	//
 
-	UT_sint32 ftcol = (UT_sint32)atoi(szFrom);
+	UT_sint32 ftcol = static_cast<UT_sint32>(atoi(szFrom));
 
 	// NOTE: this only supports the 16 colors currently handled in
 	// NOTE: the import code. everything else gets treated as black
@@ -887,3 +905,4 @@ void s_MsWord_97_Listener::_convertFontFace  (char * szDest, const char * szFrom
 	//
 	strcpy (szDest, szFrom);
 }
+
