@@ -56,7 +56,7 @@ struct ABI_EXPORT RTFFontTableItem
 	enum FontPitch { fpDefault, fpFixed, fpVariable};
 
 	RTFFontTableItem(FontFamilyEnum fontFamily, int charSet, int codepage, FontPitch pitch,
-						unsigned char* panose, char* pFontName, char* pAlternativeFontName);
+						const char* panose, const char* pFontName, const char* pAlternativeFontName);
 	~RTFFontTableItem();
 
 	FontFamilyEnum m_family;
@@ -179,6 +179,10 @@ struct ABI_EXPORT RTFProps_CellProps
 	bool      m_bHorizontalMergedFirst;
 	UT_String m_sCellProps;
 	rtfCellBorder  m_iCurBorder;
+	bool      m_bLeftBorder;
+	bool      m_bRightBorder;
+	bool      m_bTopBorder;
+	bool      m_bBotBorder;
 	UT_sint32 m_iCellx;
 };
 
@@ -387,6 +391,11 @@ struct ABI_EXPORT RTFProps_ImageProps
 	UT_uint16 scaleY;
 	UT_uint32 width;
 	UT_uint32 height;
+	bool bCrop;
+	UT_sint32 cropt;
+	UT_sint32 cropb;
+	UT_sint32 cropl;
+	UT_sint32 cropr;
 };
 
 // Section properties
@@ -443,7 +452,7 @@ struct ABI_EXPORT RTFStateStore
 {
 	RTFStateStore();
     RTFStateStore * clone();
-//	RTFStateStore& operator=(const RTFStateStore&);
+	// RTFStateStore& operator=(const RTFStateStore& s)
 
 	enum DestinationStateTypes { rdsNorm, rdsSkip, rdsFootnote, rdsHeader, rdsFooter, rdsField };
 	enum InternalStateTypes { risNorm, risBin, risHex };
@@ -457,6 +466,7 @@ struct ABI_EXPORT RTFStateStore
     RTFProps_TableProps     m_tableProps;           // Table properties
 	UT_uint32				m_unicodeAlternateSkipCount;	// value of N in "\ucN"
 	UT_uint32				m_unicodeInAlternate;			// chars left in alternate "\u<u><A>"
+	UT_UTF8String           m_revAttr;              // the revision attribute stored in abirevision
 };
 
 
@@ -492,6 +502,8 @@ public:
 	UT_sint32             m_iCurRightCell;
 	UT_sint32             m_iCurTopCell;
 	bool                  m_bPasteAfterRow;
+	UT_sint32             m_iPrevPasteTop;
+	UT_sint32             m_iNumRows;
 };
 
 // The importer/reader for Rich Text Format files
@@ -605,8 +617,14 @@ private:
 
 	bool ReadColourTable();
 	bool ReadFontTable();
-	bool ReadOneFontFromTable(bool bNested);
+	bool RegisterFont(RTFFontTableItem::FontFamilyEnum fontFamily,
+	                  RTFFontTableItem::FontPitch pitch,
+	                  UT_uint16 fontIndex,
+	                  int charSet, int codepage,
+	                  UT_UTF8String sFontNames[]);
+	bool PostProcessAndValidatePanose(UT_UTF8String &Panose);
 	bool ReadRevisionTable();
+	void setEncoding();  
 public:
 	bool HandlePicture();
 	void clearImageName(void)
@@ -645,7 +663,7 @@ private:
 	bool ReadListOverrideTable(void);
 	bool HandleTableListOverride(void);
 
-	bool buildAllProps( char * propBuffer,  RTFProps_ParaProps * pParas,
+	bool buildAllProps( UT_String & s,  RTFProps_ParaProps * pParas,
 					   RTFProps_CharProps * pChars,
 					   RTFProps_bParaProps * pbParas,
 					   RTFProps_bCharProps * pbChars);
@@ -691,6 +709,7 @@ private:
 	bool AddTabstop(UT_sint32 stopDist, eTabType tabType, 
                     eTabLeader tabLeader,  RTFProps_ParaProps * pParas);
 
+
 // Paste AbiWord tables
  public:
 	bool HandleAbiTable(void);
@@ -698,6 +717,8 @@ private:
 	bool HandleAbiEndTable(void);
 	bool HandleAbiEndCell(void);
 	bool HandleAbiLists(void);
+	bool HandleAbiMathml(void);
+	bool HandleAbiEmbed(void);
 	bool isPastedTableOpen(void);
 	bool markPasteBlock(void);
 	bool isBlockNeededForPasteTable(void);
@@ -863,6 +884,7 @@ private:
 	bool                  m_bInFootnote;
 	UT_uint32             m_iDepthAtFootnote;
 	UT_uint32             m_iLastFootnoteId;
+	UT_uint32             m_iLastEndnoteId;
 	UT_String             m_hyperlinkBase;
 	UT_uint32             m_iHyperlinkOpen;
 	bool                  m_bBidiMode;
@@ -890,6 +912,10 @@ private:
 	UT_BidiCharType       m_iBidiLastType;
 	UT_BidiCharType       m_iBidiNextType;
 
+	const char* m_szDefaultEncoding; // Document default char encoding.
+	int m_iDefaultFontNumber;        // Document default font.
+	PT_DocPosition        m_dPosBeforeFootnote;
+	bool                  m_bMovedPos;
 };
 
 #endif /* IE_IMP_RTF_H */
