@@ -339,7 +339,7 @@ void ODe_Text_Listener::closeEndnote(ODe_ListenerAction& rAction) {
 void ODe_Text_Listener::openTOC(const PP_AttrProp* pAP) {
     UT_UTF8String output;
     bool ok;
-    const XML_Char* pValue;
+    const XML_Char* pValue = 0;
     UT_uint8 outlineLevel;
     UT_UTF8String str;
     
@@ -377,20 +377,24 @@ void ODe_Text_Listener::openTOC(const PP_AttrProp* pAP) {
     ok = pAP->getProperty("toc-has-heading", pValue);
     UT_ASSERT(ok && pValue != NULL);
 
-    if (*pValue == '1') {
+    if (pValue && (*pValue == '1')) {
     
         _printSpacesOffset(output);
         output += "<text:index-title-template text:style-name=\"";
         
         ok = pAP->getProperty("toc-heading-style", pValue);
         UT_ASSERT(ok && pValue != NULL);
-        output += pValue;
+        if (ok && pValue) {
+            output += pValue;
+        }
         
         output += "\">";
         
         ok = pAP->getProperty("toc-heading", pValue);
         UT_ASSERT(ok && pValue != NULL);
-        output += pValue;
+        if (ok && pValue) {
+            output += pValue;
+        }
         
         output += "</text:index-title-template>\n";
         
@@ -418,7 +422,9 @@ void ODe_Text_Listener::openTOC(const PP_AttrProp* pAP) {
         ok = pAP->getProperty(str.utf8_str(), pValue);
         UT_ASSERT(ok && pValue != NULL);
         
-        output += pValue;
+        if (ok && pValue) {
+            output += pValue;
+        }
         
         output += "\">\n";
         m_spacesOffset++;
@@ -632,7 +638,7 @@ void ODe_Text_Listener::_openODListItem(const PP_AttrProp* pAP) {
         ok = pAP->getAttribute("listid", pValue);
         UT_ASSERT(ok && pValue!=NULL);
                 
-        if (UT_strcmp(pListLevelStyle->getAbiListID().utf8_str(), pValue) != 0) {
+        if (pListLevelStyle && (UT_strcmp(pListLevelStyle->getAbiListID().utf8_str(), pValue) != 0)) {
             // This list item belongs to a new list.
             _closeODList(); // Close the current list to start a new one later on.
         }
