@@ -258,12 +258,14 @@ bool s_KWord_1_Listener::populate(PL_StruxFmtHandle /*sfh*/,
 				// todo: support these
 			case PTO_Hyperlink:
 			case PTO_Bookmark:
+			case PTO_Math:
+			case PTO_Embed:
 			  return true;
 
 			default:
 			{
-				UT_ASSERT(0);
-				return false;
+				UT_ASSERT(UT_TODO);
+				return true;
 			}
 
 			}
@@ -350,8 +352,8 @@ bool s_KWord_1_Listener::populateStrux(PL_StruxDocHandle /*sdh*/,
 	case PTX_SectionFootnote:
 	case PTX_EndEndnote:
 	default:
-		UT_ASSERT_NOT_REACHED();
-		return false;	
+		UT_ASSERT(UT_TODO);
+		return true;
 	}
 }
 
