@@ -69,6 +69,8 @@ ABI_ListDefinition::ABI_ListDefinition(int iOutlineHash) :
 		m_iListIDs[i] = 0;
 		m_listTypes[i] = BULLETED_LIST;
 		m_iListNumbers[i] = 0;
+		m_listLeftOffset[i] = 0.0f;
+		m_listMinLabelWidth[i] = 0.0f;
 	}
 }
 
@@ -168,8 +170,11 @@ IE_Imp_WordPerfect::IE_Imp_WordPerfect(PD_Document * pDocument)
 	m_bParagraphInSection(false),
 	m_bInSection(false),
 	m_bSectionChanged(false),
-	m_leftMargin(0.0f),
-	m_rightMargin(0.0f),
+	m_leftPageMargin(1.0f),
+	m_rightPageMargin(1.0f),
+	m_leftSectionMargin(0.0f),
+	m_rightSectionMargin(0.0f),
+	m_sectionColumnsCount(0),
 	m_headerId(-1),
 	m_footerId(-1),
 	m_nextFreeId(0),
@@ -256,26 +261,20 @@ void IE_Imp_WordPerfect::openPageSpan(const WPXPropertyList &propList)
 	if (m_bHdrFtrOpenCount) return; // HACK
 	UT_DEBUGMSG(("AbiWordPerfect: openPageSpan\n"));
 	
-	float marginLeft = 0.0f, marginRight = 0.0f;
+	float marginLeft = 1.0f, marginRight = 1.0f;
 
 	if (propList["fo:margin-left"])
 		marginLeft = propList["fo:margin-left"]->getFloat();
 	if (propList["fo:margin-right"])
 		marginRight = propList["fo:margin-right"]->getFloat();
 
-	if (
-		marginLeft != m_leftMargin ||
-		marginRight != m_rightMargin //||
-		//marginTop != m_marginBottom ""
-		//marginBottom != m_marginBottom
-		)
-	{
-		m_leftMargin = marginLeft;
-		m_rightMargin = marginRight;
+	if (marginLeft != m_leftPageMargin || marginRight != m_rightPageMargin /* || */
+		/* marginTop != m_marginBottom || marginBottom != m_marginBottom */ )
+		m_bSectionChanged = true; // margin properties are section properties in AbiWord
+
+	m_leftPageMargin = marginLeft;
+	m_rightPageMargin = marginRight;
 		
-		// margin properties are section properties in AbiWord
-		m_bSectionChanged;
-	}
 }
 
 void IE_Imp_WordPerfect::openHeader(const WPXPropertyList &propList)
@@ -518,13 +517,23 @@ void IE_Imp_WordPerfect::openSection(const WPXPropertyList &propList, const WPXP
 	if (m_bHdrFtrOpenCount) return; // HACK
 	UT_DEBUGMSG(("AbiWordPerfect: openSection\n"));
 
+	float marginLeft = 0.0f, marginRight = 0.0f;
+	int columnsCount = ((columns.count() == 0) ? 1 : columns.count());
+
 	// TODO: support spaceAfter
 	if (propList["fo:margin-left"])
-		m_leftMargin = propList["fo:margin-left"]->getFloat();
+		marginLeft = propList["fo:margin-left"]->getFloat();
 	if (propList["fo:margin-right"])
-		m_rightMargin = propList["fo:margin-right"]->getFloat();
+		marginRight = propList["fo:margin-right"]->getFloat();
 
-	_appendSection((columns.count() == 0) ? 1 : columns.count(), m_leftMargin, m_rightMargin); 
+	if (marginLeft != m_leftSectionMargin || marginRight != m_rightSectionMargin || m_sectionColumnsCount != columnsCount)
+		m_bSectionChanged = true;
+
+	m_leftSectionMargin = marginLeft;
+	m_rightSectionMargin = marginRight;
+	m_sectionColumnsCount = columnsCount;
+	
+	_appendSection(columnsCount, m_leftPageMargin + m_leftSectionMargin, m_rightPageMargin + m_rightSectionMargin); 
 }
 
 void IE_Imp_WordPerfect::insertTab()
@@ -566,6 +575,8 @@ void IE_Imp_WordPerfect::defineOrderedListLevel(const WPXPropertyList &propList)
 	int listID = 0, startingNumber = 0, level = 1;
 	char listType = '1';
 	UT_UTF8String textBeforeNumber, textAfterNumber;
+	float listLeftOffset = 0.0f;
+	float listMinLabelWidth = 0.0f;
 	
 	if (propList["libwpd:id"])
 		listID = propList["libwpd:id"]->getInt();
@@ -578,9 +589,12 @@ void IE_Imp_WordPerfect::defineOrderedListLevel(const WPXPropertyList &propList)
 	if (propList["style:num-suffix"])
 		textAfterNumber += propList["style:num-suffix"]->getStr().cstr();
 	if (propList["style:num-format"])
-	{
 		listType = propList["style:num-format"]->getStr().cstr()[0];
-	}
+	if (propList["text:space-before"])
+		listLeftOffset = propList["text:space-before"]->getFloat();
+	if (propList["text:min-label-width"])
+		listMinLabelWidth = propList["text:min-label-width"]->getFloat();
+
 	if (!m_pCurrentListDefinition || 
 		m_pCurrentListDefinition->getOutlineHash() != listID ||
 		(m_pCurrentListDefinition->getLevelNumber(level) != startingNumber && 
@@ -596,6 +610,8 @@ void IE_Imp_WordPerfect::defineOrderedListLevel(const WPXPropertyList &propList)
 	{
 		m_pCurrentListDefinition->setListType(level, listType);
 		m_pCurrentListDefinition->setListID(level, UT_rand());
+		m_pCurrentListDefinition->setListLeftOffset(level, listLeftOffset);
+		m_pCurrentListDefinition->setListMinLabelWidth(level, listMinLabelWidth);
 		_updateDocumentOrderedListDefinition(m_pCurrentListDefinition, level, listType, textBeforeNumber, textAfterNumber, startingNumber);
 	}
 }
@@ -607,10 +623,17 @@ void IE_Imp_WordPerfect::defineUnorderedListLevel(const WPXPropertyList &propLis
 
 	int listID = 0, level = 1;
 	WPXString textBeforeNumber, textAfterNumber;
+	float listLeftOffset = 0.0f;
+	float listMinLabelWidth = 0.0f;
+	
 	if (propList["libwpd:id"])
 		listID = propList["libwpd:id"]->getInt();
 	if (propList["libwpd:level"])
 		level = propList["libwpd:level"]->getInt();
+	if (propList["text:space-before"])
+		listLeftOffset = propList["text:space-before"]->getFloat();
+	if (propList["text:min-label-width"])
+		listMinLabelWidth = propList["text:min-label-width"]->getFloat();
 
 	if (!m_pCurrentListDefinition || m_pCurrentListDefinition->getOutlineHash() != listID)
 	{
@@ -623,6 +646,8 @@ void IE_Imp_WordPerfect::defineUnorderedListLevel(const WPXPropertyList &propLis
 	if (!m_pCurrentListDefinition->getListID(level))
 	{
 		m_pCurrentListDefinition->setListID(level, UT_rand());
+		m_pCurrentListDefinition->setListLeftOffset(level, listLeftOffset);
+		m_pCurrentListDefinition->setListMinLabelWidth(level, listMinLabelWidth);
 		_updateDocumentUnorderedListDefinition(m_pCurrentListDefinition, level);
 	}
 }
@@ -725,16 +750,15 @@ void IE_Imp_WordPerfect::openListElement(const WPXPropertyList &propList, const
 	propBuffer += tempBuffer;
 	UT_String_sprintf(tempBuffer, "start-value:%i; ", 1);
 	propBuffer += tempBuffer;
-	if (propList["fo:text-indent"])
-	{
-		UT_String_sprintf(tempBuffer, "text-indent:%s; ", propList["fo:text-indent"]->getStr().cstr());
-		propBuffer += tempBuffer;
-	}
-	if (propList["fo:margin-left"])
-	{
-		UT_String_sprintf(tempBuffer, "margin-left:%s", propList["fo:margin-left"]->getStr().cstr());
-		propBuffer += tempBuffer;
-	}
+
+	UT_String_sprintf(tempBuffer, "margin-left:%.4fin; ", m_pCurrentListDefinition->getListLeftOffset(m_iCurrentListLevel)
+					+ m_pCurrentListDefinition->getListMinLabelWidth(m_iCurrentListLevel)
+					- (propList["fo:text-indent"] ? propList["fo:text-indent"]->getFloat() : 0.0f));
+	propBuffer += tempBuffer;
+	UT_String_sprintf(tempBuffer, "text-indent:%.4fin", - m_pCurrentListDefinition->getListMinLabelWidth(m_iCurrentListLevel)
+					+ (propList["fo:text-indent"] ? propList["fo:text-indent"]->getFloat() : 0.0f));
+	propBuffer += tempBuffer;
+
 	listAttribs[attribsCount++] = PT_PROPS_ATTRIBUTE_NAME;
 	listAttribs[attribsCount++] = propBuffer.c_str();
 	listAttribs[attribsCount++] = NULL;
@@ -992,10 +1016,7 @@ UT_Error IE_Imp_WordPerfect::_appendSection(int numColumns, const float marginLe
 	X_CheckDocumentError(appendStrux(PTX_Section, (const XML_Char**)propsArray));
 	
 	m_bInSection = true;
-	
-	m_leftMargin = marginLeft;
-	m_rightMargin = marginRight;
-	
+
 	m_bSectionChanged = false;
 	
 	return UT_OK;
