@@ -574,8 +574,8 @@ bool s_XSL_FO_Listener::populate(PL_StruxFmtHandle /*sfh*/,
 
 			default:
 			{
-				UT_ASSERT(0);
-				return false;
+				UT_ASSERT(UT_TODO);
+				return true;
 			}
 
 			}
